/**
 * vim: set ts=4 :
 * =============================================================================
 * SourceMod (C)2004-2008 AlliedModders LLC.  All rights reserved.
 * =============================================================================
 *
 * This file is part of the SourceMod/SourcePawn SDK.
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License, version 3.0, as published by the
 * Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * As a special exception, AlliedModders LLC gives you permission to link the
 * code of this program (as well as its derivative works) to "Half-Life 2," the
 * "Source Engine," the "SourcePawn JIT," and any Game MODs that run on software
 * by the Valve Corporation.  You must obey the GNU General Public License in
 * all respects for all other code used.  Additionally, AlliedModders LLC grants
 * this exception to all derivative works.  AlliedModders LLC defines further
 * exceptions, found in LICENSE.txt (as of this writing, version JULY-31-2007),
 * or <http://www.sourcemod.net/license.php>.
 *
 */

#if defined _system_included
#endinput
#endif
#define _system_included

/* process priority, creation flags. more in here 
http://msdn.microsoft.com/en-us/library/ms684863(VS.85).aspx */
#define PRI_LOW				0x00000040
#define PRI_BELOWNORMAL		0x00004000
#define PRI_NORMAL			0x00000020
#define PRI_ABOVENORMAL		0x00008000
#define PRI_HIGH			0x00000080
#define PRI_REALTIME		0x00000100
#define CREATE_NEW_CONSOLE	0x00000010

#define SW_HIDE             0
#define SW_SHOWNORMAL       1
#define SW_NORMAL           1
#define SW_SHOWMINIMIZED    2
#define SW_SHOWMAXIMIZED    3
#define SW_MAXIMIZE         3
#define SW_SHOWNOACTIVATE   4
#define SW_SHOW             5
#define SW_MINIMIZE         6
#define SW_SHOWMINNOACTIVE  7
#define SW_SHOWNA           8
#define SW_RESTORE          9
#define SW_SHOWDEFAULT      10
#define SW_FORCEMINIMIZE    11
#define SW_MAX              11

/**
 * Execute any system command/prcoess.
 *
 * @param command			String of command.
 *							(if command include "format","../","..\"(case insensitive)
 *							command will not run/blocked and wirte the command in sourcemod log)
 * @param priority			New Process priority.
 * @param ShowWindow		Show Process window.
 * @return					true/false. (false = command blocked)
 */
native bool:RunSystemCommand(const String:command[],flags=PRI_NORMAL|CREATE_NEW_CONSOLE,SW_flag=SW_SHOW);

/**
 * Do RC4 (Rivest Cipher 4) encryption http://en.wikipedia.org/wiki/RC4
 *
 * @param plaintext			String of plaintext.
 * @param pwd				Password of RC4 encryption.
 * @param ciphertext		Output string buffer.
 * @param maxlength			Output string buffer maxlength.
 * @param IsLowerCase		true/false. (true = Hexadecimal using "a-f")
 * @return					true/false. (true = encryption success)
 */
native bool:Rc4Encryption(const String:plaintext[], const String:pwd[], String:ciphertext[], maxlength,bool:IsLowerCase=true);

/**
 * Do RC4 (Rivest Cipher 4) dencryption http://en.wikipedia.org/wiki/RC4
 *
 * @param plaintext			String of ciphertext.
 *							(ciphertext Hexadecimal can be lowercase or uppercase)
 * @param pwd				Password of RC4 dencryption.
 * @param ciphertext		Output string buffer.
 * @param maxlength			Output string buffer maxlength.
 * @return					true/false. (true = dencryption success)
 */
native bool:Rc4Dencryption(const String:ciphertext[], const String:pwd[], String:plaintext[], maxlength);

/**
 * Do MD5 32bit (Message-Digest algorithm 5) encryption http://en.wikipedia.org/wiki/MD5
 *
 * @param plaintext			String of plaintext.
 * @param output			Output string buffer.
 * @param maxlength			Output string buffer maxlength.
 * @param IsLowerCase		true/false. (true = Hexadecimal using "a-f")
 * @param UseASM			true/false. (WINDOWS PLATFORM ONLY,
 *										 realize MD5 algorithm in ASM to achieve high speed, speed up ~20%)
 * @noreturn
 */
native Md5Encryption(const String:plaintext[], String:output[], maxlength, bool:IsLowerCase=true, bool:UseASM=false);

/**
 *	Returns a random String.
 * @param output				Output string buffer.
 * @param maxlength				Output string buffer maxlength.
 * @param length				The length of the random string. (maximum 128)
 * @param IncludeNumber 		true/false.     (true = include "0-9")
 * @param IncludeLowerCase 		true/false.     (true = include "a-z")
 * @param IncludeUperCase 		true/false.     (true = include "A-Z")
 * @param IncludeSymbol 		true/false.     (true = include
 *												! \" # $ % & ' ( ) * + , - . / : ; < = > ? [ \\ ] ^ _ ` { | } ~
 *												NOT include SPACE " ")
 * @return						true/false (false = 4 "Include" are false)
 */
native bool:GetRandomString(String:output[], maxlength, length = 8, bool:IncludeNumber=true, bool:IncludeLowerCase=true,  bool:IncludeUperCase=true, bool:IncludeSymbol=true);

public Extension:__ext_system =
{
	name = "System Extension",
	file = "system.ext",
#if defined AUTOLOAD_EXTENSIONS
	autoload = 1,
#else
	autoload = 0,
#endif
#if defined REQUIRE_EXTENSIONS
	required = 1,
#else
	required = 0,
#endif
};
